Learn R Programming

poputils (version 0.6.1)

nzl_mort_rvec: Mortality Data and Probabilistic Rates for New Zealand

Description

A modified version of link{nzl_mort} where mx columns is an rvec, rather than an ordinary R vector. The rvec holds the random draws from the posterior distribution obtained from by a Bayesian statistical model.

Usage

nzl_mort_rvec

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 84 rows and 4 columns.